searchData={"items":[{"type":"module","title":"RealmOsintEx","doc":"RealmOsintEx is an OSINT tool built with Elixir for querying Microsoft's GetUserRealm endpoint using Req.\n\nThis library uses a fixed username prefix (`\"username@\"`) so that callers only need to supply a domain (e.g., `\"example.com\"`).\nThe full login is then constructed as `\"username@example.com\"`.\n\nThe JSON response from the endpoint varies based on the domain’s configuration.\n\n**For a Federated Domain**, the response may include:\n\n  - `\"State\"`: integer status (e.g., 3, meaning federated).\n  - `\"UserState\"`: integer providing additional context.\n  - `\"Login\"`: full user login (e.g., `\"username@example.com\"`).\n  - `\"NameSpaceType\"`: typically `\"Federated\"`.\n  - `\"DomainName\"`: the domain (e.g., `\"example.com\"`).\n  - `\"FederationGlobalVersion\"`: integer version (often `-1`).\n  - `\"AuthURL\"`: URL to redirect for federated authentication.\n  - `\"FederationBrandName\"`: the identity provider's brand.\n  - `\"AuthNForwardType\"`: an integer indicating the authentication forwarding type.\n  - `\"CloudInstanceName\"`: usually `\"microsoftonline.com\"`.\n  - `\"CloudInstanceIssuerUri\"`: the issuer URI for the cloud instance.\n\n**For an Unknown Domain**, the response may only include:\n\n  - `\"State\"`: an integer (e.g., 4, meaning non-federated).\n  - `\"UserState\"`: integer providing additional context.\n  - `\"Login\"`: the constructed login.\n  - `\"NameSpaceType\"`: typically `\"Unknown\"`.\n\nThis tool empowers OSINT investigations by quickly identifying a domain's authentication configuration.","ref":"RealmOsintEx.html"},{"type":"function","title":"RealmOsintEx.get_realm/2","doc":"Retrieves user realm information for a given domain using Req.\n\nA fixed username prefix of `\"username@\"` is used to build the login,\nso you only need to pass the domain (e.g., `\"example.com\"`).","ref":"RealmOsintEx.html#get_realm/2"},{"type":"function","title":"Parameters - RealmOsintEx.get_realm/2","doc":"- domain: A string representing the domain (e.g., `\"example.com\"`).","ref":"RealmOsintEx.html#get_realm/2-parameters"},{"type":"function","title":"Returns - RealmOsintEx.get_realm/2","doc":"- `{:ok, map}` with keys such as:\n      - `\"State\"`: integer\n      - `\"UserState\"`: integer\n      - `\"Login\"`: string (e.g., `\"username@example.com\"`)\n      - `\"NameSpaceType\"`: string\n      - `\"DomainName\"`: string (if provided)\n      - `\"FederationGlobalVersion\"`: integer (if provided)\n      - `\"AuthURL\"`: string (if provided)\n      - `\"FederationBrandName\"`: string (if provided)\n      - `\"AuthNForwardType\"`: integer (if provided)\n      - `\"CloudInstanceName\"`: string (if provided)\n      - `\"CloudInstanceIssuerUri\"`: string (if provided)\n\n  - `{:error, reason}` if the HTTP request or JSON processing fails.","ref":"RealmOsintEx.html#get_realm/2-returns"},{"type":"function","title":"RealmOsintEx.parse_xml/1","doc":"","ref":"RealmOsintEx.html#parse_xml/1"},{"type":"extras","title":"RealmOsintEx","doc":"# RealmOsintEx\n---\n\nRealmOsintEx is an OSINT tool built with Elixir for querying Microsoft's GetUserRealm endpoint. It enables efficient investigation of a domain’s authentication configuration by constructing a standardized login using a fixed prefix (`\"username@\"`) and a provided domain.\n\n---","ref":"readme.html"},{"type":"extras","title":"Overview - RealmOsintEx","doc":"When querying Microsoft’s GetUserRealm endpoint, RealmOsintEx returns a map containing various keys that describe the authentication realm of the specified domain. The response structure can vary depending on the domain’s configuration, and you can generally expect one of two types:\n\n- **Federated Domains**  \n  These responses contain a rich set of fields that indicate the domain is using federation for authentication. Typical keys include:\n  - **\"State\"**: An integer that represents the domain’s authentication status (commonly `3` for federated domains).\n  - **\"UserState\"**: An integer with additional context (often `2` for federated setups).\n  - **\"Login\"**: A string with the constructed login (e.g., `\"username@example.com\"`).\n  - **\"NameSpaceType\"**: Typically `\"Federated\"`.\n  - **\"DomainName\"**: The queried domain (e.g., `\"example.com\"`).\n  - **\"AuthNForwardType\"**: An integer signaling how authentication requests should be forwarded.\n  - **\"AuthURL\"**: A URL to which authentication requests should be directed.\n  - **\"FederationBrandName\"**: The brand name of the identity provider (for example, a customized provider name).\n  - **\"FederationGlobalVersion\"**: An integer indicating the configuration version (commonly `-1`).\n  - **\"CloudInstanceName\"** and **\"CloudInstanceIssuerUri\"**: Information on the Microsoft Online instance handling the authentication.\n\n- **Unknown or Managed Domains**  \n  For domains that are not federated or use a different type of authentication, the endpoint is likely to return a more limited data set such as:\n  - **\"State\"**: A numerical code (e.g., `4` for non-federated domains).\n  - **\"UserState\"**: Often a basic context indicator (commonly `1`).\n  - **\"Login\"**: The constructed login.\n  - **\"NameSpaceType\"**: Generally reported as `\"Unknown\"`, reflecting that federated details are not provided.\n\nEach key provides detailed insight into how authentication is handled for the domain, making RealmOsintEx a valuable addition to any OSINT toolkit.\n\n---","ref":"readme.html#overview"},{"type":"extras","title":"Features - RealmOsintEx","doc":"- **Simple Domain Lookup:** Only supply the domain (e.g., `example.com`) and the tool constructs the login (`\"username@example.com\"`) automatically.\n- **OSINT Integration:** Quickly determine if a domain is federated (with detailed configuration) or unknown/managed.\n- **Robust HTTP Handling:** Uses the Req library for HTTP requests, with graceful parsing of JSON responses whether in binary form or already decoded.\n- **Detailed Authentication Mapping:** Provides insights into authentication redirection, federation branding, and cloud instance configurations.\n\n---","ref":"readme.html#features"},{"type":"extras","title":"Installation - RealmOsintEx","doc":"Add RealmOsintEx to your Elixir project by updating your `mix.exs` dependencies:\n\n```elixir\ndefp deps do\n  [\n    {:realm_osint_ex, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen fetch the dependencies:\n\n```bash\nmix deps.get\n```\n\n---","ref":"readme.html#installation"},{"type":"extras","title":"Usage - RealmOsintEx","doc":"RealmOsintEx makes it easy to query the Microsoft GetUserRealm endpoint. For example, querying for `example.com`:\n\n```elixir\niex> RealmOsintEx.get_realm(\"example.com\")\n{:ok,\n %{\n   \"AuthNForwardType\" => 1,\n   \"AuthURL\" =>\n     \"https://sts.microsoftonline.com/Trust/2005/UsernameMixed?username=username%40example.com&wa=wsignin1.0&wtrealm=urn%3afederation%3aMicrosoftOnline&wctx=\",\n   \"CloudInstanceIssuerUri\" => \"urn:federation:MicrosoftOnline\",\n   \"CloudInstanceName\" => \"microsoftonline.com\",\n   \"DomainName\" => \"example.com\",\n   \"FederationBrandName\" => \"test_test_06102020MM\",\n   \"FederationGlobalVersion\" => -1,\n   \"Login\" => \"username@example.com\",\n   \"NameSpaceType\" => \"Federated\",\n   \"State\" => 3,\n   \"UserState\" => 2\n }}\n```\n\nFor unknown or managed domains, the returned map will mainly include minimal keys like `\"State\"`, `\"UserState\"`, `\"Login\"`, and `\"NameSpaceType\"` (typically set to `\"Unknown\"`).\n\n---","ref":"readme.html#usage"},{"type":"extras","title":"Building and Running - RealmOsintEx","doc":"1. **Create a New Project** (if you haven't already):\n\n   ```bash\n   mix new realm_osint_ex\n   ```\n\n2. **Navigate into the Project Directory:**\n\n   ```bash\n   cd realm_osint_ex\n   ```\n\n3. **Add and Fetch Dependencies:**\n\n   Update your `mix.exs` and run:\n\n   ```bash\n   mix deps.get\n   ```\n\n4. **Compile the Project:**\n\n   ```bash\n   mix compile\n   ```\n\n5. **Start an Interactive Shell (IEx):**\n\n   ```bash\n   iex -S mix\n   ```\n\n6. **Test the Module:**\n\n   At the IEx prompt, run:\n\n   ```elixir\n   RealmOsintEx.get_realm(\"example.com\")\n   ```\n\nIf needed, you can build a release using:\n\n```bash\nmix release\n```\n\n---","ref":"readme.html#building-and-running"},{"type":"extras","title":"Contributing - RealmOsintEx","doc":"Contributions are welcome! Please open issues or submit pull requests if you find bugs, have feature requests, or would like to help improve RealmOsintEx.\n\n---","ref":"readme.html#contributing"},{"type":"extras","title":"License - RealmOsintEx","doc":"RealmOsintEx is released under the BSD 3-Clause License. This license permits redistribution and use in source and binary forms, with or without modification, as long as the following conditions are met:\n\n- Redistributions of source code must retain the BSD 3-clause license notice.\n- Redistributions in binary form must reproduce the BSD 3-clause license notice in the documentation and/or other materials provided with the distribution.\n- Neither the name of the author nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.\n\nSee the LICENSE file for the full text of the license.\n\n---\n\nRealmOsintEx provides a straightforward and efficient approach to integrating Microsoft's authentication realm discovery into your OSINT workflows. Enjoy exploring, investigating, and enhancing your domain intelligence capabilities with RealmOsintEx!","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}